# -*- coding: utf-8 -*-
import logging
import itertools

from chibi_atlas import Chibi_atlas


logger = logging.getLogger( "chibi_sshd.snippets" )


def from_string( content ):
    lines = content.split( "\n" )
    lines = map( str.strip, lines )
    lines = filter( bool, lines )
    lines = itertools.filterfalse( line_is_comment, lines )
    return Chibi_atlas( dict( map( parse_line, lines ) ) )


def to_string( content ):
    return "\n".join( ( to_line( k, v ) for k, v in content.items() ) )


def line_is_comment( line ):
    return line.startswith( "#" )


def parse_line( line ):
    k, v = line.split( maxsplit=1 )
    if '#' in v:
        v, trash = v.split( "#", 1 )
    k = k.strip()
    v = v.strip()
    if v == 'no':
        v = False
    elif v == 'yes':
        v = True
    if k == 'AllowUsers':
        v = v.split()
    return k, v


def to_line( k, v ):
    if isinstance( v, bool ):
        if v:
            v = 'yes'
        else:
            v = 'no'
    if k == 'AllowUsers':
        if isinstance( v, list ):
            v = " ".join( v )
        elif isinstance( v, str ):
            v = v
        else:
            raise NotImplementedError(
                "no esta implementado que AllowUsers sea de "
                f"tipo {type(v)} con el valor de '{v}'"
            )
    return f"{k} {v}"



# -*- coding: utf-8 -*-
from chibi.file import Chibi_file
from chibi_sshd.snippets import to_string, from_string
from chibi_hybrid import Class_property


class Chibi_sshd_conf( Chibi_file ):
    @Class_property
    def default( cls ):
        """
        atajo para leer el sshd config del sistema
        """
        return cls( "/etc/ssh/sshd_config" )

    def read( self ):
        string = super().read()
        result = from_string( string )
        return result

    def write( self, data ):
        result = to_string( data )
        super().write( result )


class Chibi_authorized_keys( Chibi_file ):
    @Class_property
    def default( cls ):
        """
        atajo para leer el las llaves autorizadas del user
        """
        return cls( "~/.ssh/authorized_keys" )

    def read( self ):
        string = super().read()
        result = string.split( '\n' )
        return result

    def write( self, data ):
        if isinstance( data, list ):
            result = "\n".join( data )
        else:
            raise NotImplementedError
        super().write( result )

    def append( self, data ):
        if isinstance( data, str ):
            current = self.read()
            current.append( data )
            self.write( current )
        else:
            raise NotImplementedError



# -*- coding: utf-8 -*-
from .file import Chibi_sshd_conf, Chibi_authorized_keys

__all__ = [ 'Chibi_sshd_conf', 'Chibi_authorized_keys' ]


__author__ = """dem4ply"""
__email__ = 'dem4ply@gmail.com'
__version__ = '1.1.0'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'chibi>=0.17.0', "chibi_atlas>=1.1.0", "chibi_hybrid>=1.2.1"
]

setup(
    author="dem4ply",
    author_email='dem4ply@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: Public Domain',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="package for handling config files of ssh like sshd_config and authorized_keys",
    install_requires=requirements,
    license="WTFPL",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='chibi_sshd',
    name='chibi_sshd',
    packages=find_packages(include=['chibi_sshd', 'chibi_sshd.*']),
    url='https://github.com/dem4ply/chibi_sshd',
    version='1.1.0',
    zip_safe=False,
)
